@@ -134,7 +134,7 @@ plotEqn <- function(A, b, vars, xlim=c(-4, 4), ylim,
 #' plotEqn3d(A,b)
 
 plotEqn3d <- function( A, b, vars, xlim=c(-2,2), ylim=c(-2,2), zlim,
-                       col=2:(nrow(A)+1), alpha=0.5, labels=FALSE, solution=TRUE)
+                       col=2:(nrow(A)+1), alpha=1, labels=FALSE, solution=TRUE)
 {
 
   if (!requireNamespace("rgl", quietly = TRUE)) {
