@@ -10,7 +10,7 @@
 #' @param X          a vector or three-column matrix representing a set of geometric vectors; if a matrix, one vector is drawn for each row
 #' @param origin     the origin from which they are drawn, a vector of length 3.
 #' @param headlength the \code{headlength} argument passed to \code{\link{arrows3d}} determining the length of arrow heads
-#' @param ref.length vector length to be used in scalling arrow heads so that they are all the same size; if \code{NULL}
+#' @param ref.length vector length to be used in scaling arrow heads so that they are all the same size; if \code{NULL}
 #'        the longest vector is used to scale the arrow heads
 #' @param radius     radius of the base of the arrow heads
 #' @param labels     a logical or a character vector of labels for the vectors. If \code{TRUE} and \code{X} is a matrix,
@@ -20,6 +20,7 @@
 #' @param adj.lab    label position relative to the label point as in \code{\link[rgl]{text3d}}, recycled as necessary.
 #' @param frac.lab   location of label point, as a fraction of the distance between \code{origin} and \code{X}, recycled as necessary.
 #'        Values \code{frac.lab > 1} locate the label beyond the end of the vector.
+#' @param draw       if \code{TRUE} (the default), draw the vector(s).
 #' @param ...        other arguments passed on to graphics functions.
 #'
 #' @return invisibly returns the vector \code{ref.length} used to scale arrow heads
@@ -56,7 +57,7 @@
 
 vectors3d <- function(X, origin=c(0,0,0),
                        headlength=0.035, ref.length=NULL, radius=1/60,
-                       labels=TRUE, cex.lab=1.2, adj.lab=0.5, frac.lab=1.1,  ...) {
+                       labels=TRUE, cex.lab=1.2, adj.lab=0.5, frac.lab=1.1, draw=TRUE, ...) {
 
   if (is.vector(X)) X <- matrix(X, ncol=3)
   n <- nrow(X)
@@ -66,18 +67,20 @@ vectors3d <- function(X, origin=c(0,0,0),
   scale <- c(1, 1, 1)
 #  radius <- 1/60
   ref.length <- arrows3d(OX, headlength=headlength, scale=scale, radius=radius,
-                         ref.length=ref.length, ...)
-
-  if (is.logical(labels) && labels) {
-    labels <- rownames(X)
-  }
-  if (!is.null(labels)) {
-    # DONE: allow for labels to be positioned some fraction of the way from origin to X
-    # FIXME: it is dangerous to use ... for both arrows3d() and text3d(), e.g., for col=
-    xl = origin[1] + frac.lab * (X[,1]-origin[1])
-    yl = origin[2] + frac.lab * (X[,2]-origin[2])
-    zl = origin[3] + frac.lab * (X[,3]-origin[3])
-    text3d(xl, yl, zl, labels, cex=cex.lab, adj=adj.lab, ...)
+                         ref.length=ref.length, draw=draw, ...)
+  
+  if (draw){
+    if (is.logical(labels) && labels) {
+      labels <- rownames(X)
+    }
+    if (!is.null(labels)) {
+      # DONE: allow for labels to be positioned some fraction of the way from origin to X
+      # FIXME: it is dangerous to use ... for both arrows3d() and text3d(), e.g., for col=
+      xl = origin[1] + frac.lab * (X[,1]-origin[1])
+      yl = origin[2] + frac.lab * (X[,2]-origin[2])
+      zl = origin[3] + frac.lab * (X[,3]-origin[3])
+      text3d(xl, yl, zl, labels, cex=cex.lab, adj=adj.lab, ...)
+    }
   }
   invisible(c(ref.length=ref.length))
 }
