@@ -48,4 +48,13 @@ tr(crossprod(A))
 
 ## ------------------------------------------------------------------------
 L^2
+cumsum(L^2)   # cumulative
+
+## ------------------------------------------------------------------------
+R(A1)
+R(A1 + A2)
+R(A1 + A2 + A3)
+# two dimensions
+sum((A1+A2)^2)
+sum((A1+A2)^2) / sum(A^2)   # proportion
 
